==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/error/ShouldNotHaveSameHashCode_create_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.error;

import static java.lang.String.format;
import static org.assertj.core.api.BDDAssertions.then;
import static org.assertj.core.error.ShouldNotHaveSameHashCode.shouldNotHaveSameHashCode;

import org.assertj.core.internal.TestDescription;
import org.assertj.core.presentation.StandardRepresentation;
import org.assertj.core.test.Jedi;
import org.junit.jupiter.api.Test;

class ShouldNotHaveSameHashCode_create_Test {

  @Test
  void should_create_error_message() {
    // GIVEN
    Jedi yoda = new Jedi("Yoda", "green");
    ErrorMessageFactory factory = shouldNotHaveSameHashCode(yoda, yoda);
    // WHEN
    String message = factory.create(new TestDescription("Test"), new StandardRepresentation());
    // THEN
    then(message).isEqualTo(format("[Test] %nExpecting%n" +
                                   "  Yoda the Jedi%n" +
                                   "not to have the same hash code as:%n" +
                                   "  Yoda the Jedi%n" +
                                   "hash code is%n" +
                                   "  88361505"));
  }
}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/error/ShouldNotHaveSameHashCode_create_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.error;

import static java.lang.String.format;
import static org.assertj.core.api.BDDAssertions.then;
import static org.assertj.core.error.ShouldNotHaveSameHashCode.shouldNotHaveSameHashCode;

import org.assertj.core.internal.TestDescription;
import org.assertj.core.presentation.StandardRepresentation;
import org.assertj.core.testkit.Jedi;
import org.junit.jupiter.api.Test;

class ShouldNotHaveSameHashCode_create_Test {

  @Test
  void should_create_error_message() {
    // GIVEN
    Jedi yoda = new Jedi("Yoda", "green");
    ErrorMessageFactory factory = shouldNotHaveSameHashCode(yoda, yoda);
    // WHEN
    String message = factory.create(new TestDescription("Test"), new StandardRepresentation());
    // THEN
    then(message).isEqualTo(format("[Test] %nExpecting%n" +
                                   "  Yoda the Jedi%n" +
                                   "not to have the same hash code as:%n" +
                                   "  Yoda the Jedi%n" +
                                   "hash code is%n" +
                                   "  88361505"));
  }
}
